#ifndef NT2_INCLUDE_FUNCTIONS_ISSYMETRIC_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISSYMETRIC_HPP_INCLUDED

#include <nt2/predicates/include/functions/issymetric.hpp>

#endif
